==> vtigercrm-5.3.0p0.tgz: modules/HelpDesk/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|07/09/2011|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
// Added in release 4.0
'LBL_MODULE_NAME'=>'Tickets',
'LBL_GROUP'=>'Grupo',
'LBL_ACCOUNT_NAME'=>'Nome Conta',
'LBL_CONTACT_NAME'=>'Nome Contato',
'LBL_SUBJECT'=>'Assunto',
'LBL_NEW_FORM_TITLE' => 'Novo Ticket',
'LBL_DESCRIPTION'=>'Descrição',
'NTC_DELETE_CONFIRMATION'=>'Você tem certeza que deseja deletar este registro?',
'LBL_CUSTOM_FIELD_SETTINGS'=>'Configurações Campos Customizados:',
'LBL_PICKLIST_FIELD_SETTINGS'=>'Configurações Campos Lista Opções:',
'Leads'=>'Lead',
'Accounts'=>'Conta',
'Contacts'=>'Contato',
'Opportunities'=>'Oportunidade',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',

'LBL_ACCOUNT'=>'Conta',
'LBL_OPPURTUNITY'=>'Oportunidade',
'LBL_PRODUCT'=>'Produto',

'LBL_COLON'=>':',
'LBL_TICKET'=>'Ticket',
'LBL_CONTACT'=>'Contato',
'LBL_STATUS'=>'Status',
'LBL_ASSIGNED_TO'=>'Responsável',
'LBL_FAQ'=>'FAQ',
'LBL_VIEW_FAQS'=>'Visualizar FAQs',
'LBL_ADD_FAQS'=>'Adicionar FAQs',
'LBL_FAQ_CATEGORIES'=>'Categorias FAQ',

'LBL_PRIORITY'=>'Prioridade',
'LBL_CATEGORY'=>'Categoria',

'LBL_ANSWER'=>'Resposta',
'LBL_COMMENTS'=>'Comentários',

'LBL_AUTHOR'=>'Autor',
'LBL_QUESTION'=>'Questão',

//Added vtiger_fields for File Attachment and Mail send in Tickets
'LBL_ATTACHMENTS'=>'Anexos',
'LBL_NEW_ATTACHMENT'=>'Novo Anexo',
'LBL_SEND_MAIL'=>'Enviar Email',

//Added vtiger_fields for search option  in TicketsList -- 4Beta
'LBL_CREATED_DATE'=>'Data Criação',
'LBL_IS'=>'é',
'LBL_IS_NOT'=>'não é',
'LBL_IS_BEFORE'=>'é antes',
'LBL_IS_AFTER'=>'é depois',
'LBL_STATISTICS'=>'Estatísticas',
'LBL_TICKET_ID'=>'No. Ticket',
'LBL_MY_TICKETS'=>'Meus Tickets',
"LBL_MY_FAQ"=>"Minhas FAQs",
'LBL_ESTIMATED_FINISHING_TIME'=>'Tempo Estimado de Conclusão',
'LBL_SELECT_TICKET'=>'Selecionar Ticket',
'LBL_CHANGE_OWNER'=>'Mudar Proprietário',
'LBL_CHANGE_STATUS'=>'Mudar Status',
'LBL_TICKET_TITLE'=>'Título',
'LBL_TICKET_DESCRIPTION'=>'Descrição',
'LBL_TICKET_CATEGORY'=>'Categoria',
'LBL_TICKET_PRIORITY'=>'Prioridade',

//Added vtiger_fields after 4 -- Beta
'LBL_NEW_TICKET'=>'Novo Ticket',
'LBL_TICKET_INFORMATION'=>'Dados do Ticket',

'LBL_LIST_FORM_TITLE'=>'Lista de Tickets',
'LBL_SEARCH_FORM_TITLE'=>'Busca de Ticket',

//Added vtiger_fields after RC1 - Release
'LBL_CHOOSE_A_VIEW'=>'Selecione uma Visualização...',
'LBL_ALL'=>'Todos',
'LBL_LOW'=>'Baixa',
'LBL_MEDIUM'=>'Média',
'LBL_HIGH'=>'Alta',
'LBL_CRITICAL'=>'Crítica',
//Added vtiger_fields for 4GA
'Assigned To'=>'Responsável',
'Contact Name'=>'Nome Contato',
'Priority'=>'Prioridade',
'Status'=>'Status',
'Category'=>'Categoria',
'Update History'=>'Histórico do Update',
'Created Time'=>'Hora Criação',
'Modified Time'=>'Hora Modificação',
'Title'=>'Título',
'Description'=>'Descrição',

'LBL_TICKET_CUMULATIVE_STATISTICS'=>'Estatísticas Cumulativa do Ticket:',
'LBL_CASE_TOPIC'=>'Tópico do Caso',
'LBL_OPEN'=>'Aberto',
'LBL_CLOSED'=>'Fechado',
'LBL_TOTAL'=>'Total',
'LBL_TICKET_HISTORY'=>'Histórico do Ticket:',
'LBL_CATEGORIES'=>'Categorias',
'LBL_PRIORITIES'=>'Prioridades',
'LBL_SUPPORTERS'=>'Suporte',

//Added vtiger_fields after 4_0_1
'LBL_TICKET_RESOLUTION'=>'Dados da Solução',
'Solution'=>'Solução',
'Add Comment'=>'Adicionar Comentário',
'LBL_ADD_COMMENT'=>'Adicionar Comentário',//give the same value given to the above string 'Add Comment'

//Added for 4.2 Release -- CustomView
'Ticket ID'=>'No. Ticket',
'Subject'=>'Assunto',

//Added after 4.2 alpha
'Severity'=>'Gravidade',
'Product Name'=>'Nome Produto',
'Related To'=>'Relacionado à',
'LBL_MORE'=>'Mais',

'LBL_TICKETS'=>'Tickets',

//Added on 09-12-2005
'LBL_CUMULATIVE_STATISTICS'=>'Estatísticas Acumuladas',

//Added on 12-12-2005
'LBL_CONVERT_AS_FAQ_BUTTON_TITLE'=>'Converter em FAQ',
'LBL_CONVERT_AS_FAQ_BUTTON_KEY'=>'C',
'LBL_CONVERT_AS_FAQ_BUTTON_LABEL'=>'Converter em FAQ',
'Attachment'=>'Anexo',
'LBL_COMMENT_INFORMATION'=> 'Informação Observações',

//Added for existing picklist entries

'Big Problem'=>'Problema Grande',
'Small Problem'=>'Problema Pequeno',
'Other Problem'=>'Outro Problema',

'Low'=>'Baixa',
'Normal'=>'Normal',
'High'=>'Alta',
'Urgent'=>'Urgente',

'Minor'=>'Menor',
'Major'=>'Maior',
'Feature'=>'Normal',
'Critical'=>'Crítico',

'Open'=>'Aberto',
'In Progress'=>'Em Processo',
'Wait For Response'=>'Aguarda Resposta',
'Closed'=>'Fechado',

//added to support i18n in ticket mails
'Hi' => 'Olá',
'Dear'=> 'Prezado(a)',
'LBL_PORTAL_BODY_MAILINFO' => 'O Ticket em referência foi',
'LBL_DETAIL' => 'e os detalhes do mesmo são apresentados abaixo:',
'LBL_REGARDS'=> 'Cordialmente',
'LBL_TEAM'=> 'Equipe HelpDesk',
'LBL_TICKET_DETAILS' => 'Detalhes Ticket',
'LBL_SUBJECT' => 'Assunto : ',
'created' => 'criado',
'replied' => 'respondido',
'reply'=>'Existe uma resposta para',
'customer_portal' => ' no nosso "Portal do Cliente".',
'link' => ' Você pode utilizar o seguinte link para visualizar a resposta:',
'Thanks' => 'Obrigado',
'Support_team' => 'Equipe Suporte vtiger',
'The comments are' => 'Os comentários são',
'Ticket Title' => 'Título Ticket',
'Re' => 'Re :',
// Added/Updated for vtiger CRM 5.0.4

//this label for customerportal.
'LBL_STATUS_CLOSED' =>'Closed',//Do not convert this label. This is used to check the status. If the status 'Closed' is changed in vtigerCRM server side then you have to change in customerportal language file also.
'LBL_STATUS_UPDATE' => 'Status do Ticket foi atualizado como',
'LBL_COULDNOT_CLOSED' => 'O Ticket não pode ser',
'LBL_CUSTOMER_COMMENTS' => 'O Cliente forneceu a seguinte informação adicional para sua resposta:',
'LBL_RESPOND'=> 'Por gentileza, responda este ticket o mais rápido possível.',
'LBL_REGARDS' =>'Cordialmente',
'LBL_SUPPORT_ADMIN' => 'Administrador Suporte',
'LBL_RESPONDTO_TICKETID' =>'Responder Ticket No.',
'LBL_CUSTOMER_PORTAL' => ' no Portal do Cliente - URGENTE',
'LBL_LOGIN_DETAILS' => 'Estes são seus detalhes de login no Portal do Cliente :',
'LBL_MAIL_COULDNOT_SENT' =>'A mensagem não pode ser enviada',
'LBL_USERNAME' => 'Nome Usuário :',
'LBL_PASSWORD' => 'Senha :',
'LBL_SUBJECT_PORTAL_LOGIN_DETAILS' => 'Observar os detalhes de login no Portal do Cliente',
'LBL_GIVE_MAILID' => 'Por gentileza, informe seu e-mail',
'LBL_CHECK_MAILID' => 'Por favor, verifique seu e-mail para o Portal do Cliente',
'LBL_LOGIN_REVOKED' => 'Seu login foi cancelado. Por favor, contacte o Administrador do Sistema.',
'LBL_MAIL_SENT' => 'Mensagem enviada para seu e-mail com detalhes do login no Portal do Cliente.',
'LBL_ALTBODY' => 'Este é o corpo da mensagem em texto simples para programas de e-mail que não suportam HTML',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Ticket No' => 'No. Ticket',
// END

'Hours' => 'Horas',
'Days' => 'Dias',
);

?>

==> vtigercrm-5.4.0.tgz: modules/HelpDesk/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for Help Desk
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
// Added in release 4.0
'LBL_MODULE_NAME'=>'Tickets',
'LBL_GROUP'=>'Grupo',
'LBL_ACCOUNT_NAME'=>'Nome Organização',
'LBL_CONTACT_NAME'=>'Nome Contato',
'LBL_SUBJECT'=>'Assunto',
'LBL_NEW_FORM_TITLE' => 'Novo Ticket',
'LBL_DESCRIPTION'=>'Descrição',
'NTC_DELETE_CONFIRMATION'=>'Você tem certeza que deseja deletar este registro?',
'LBL_CUSTOM_FIELD_SETTINGS'=>'Configurações Campos Customizados:',
'LBL_PICKLIST_FIELD_SETTINGS'=>'Configurações Campos Lista Opções:',
'Leads'=>'Lead',
'Accounts'=>'Organização',
'Contacts'=>'Contato',
'Opportunities'=>'Oportunidade',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',

'LBL_ACCOUNT'=>'Organização',
'LBL_OPPURTUNITY'=>'Oportunidade',
'LBL_PRODUCT'=>'Produto',

'LBL_COLON'=>':',
'LBL_TICKET'=>'Ticket',
'LBL_CONTACT'=>'Contato',
'LBL_STATUS'=>'Status',
'LBL_ASSIGNED_TO'=>'Responsável',
'LBL_FAQ'=>'FAQ',
'LBL_VIEW_FAQS'=>'Visualizar FAQs',
'LBL_ADD_FAQS'=>'Adicionar FAQs',
'LBL_FAQ_CATEGORIES'=>'Categorias FAQ',

'LBL_PRIORITY'=>'Prioridade',
'LBL_CATEGORY'=>'Categoria',

'LBL_ANSWER'=>'Resposta',
'LBL_COMMENTS'=>'Comentários',

'LBL_AUTHOR'=>'Autor',
'LBL_QUESTION'=>'Questão',

//Added vtiger_fields for File Attachment and Mail send in Tickets
'LBL_ATTACHMENTS'=>'Anexos',
'LBL_NEW_ATTACHMENT'=>'Novo Anexo',
'LBL_SEND_MAIL'=>'Enviar Email',

//Added vtiger_fields for search option  in TicketsList -- 4Beta
'LBL_CREATED_DATE'=>'Data Criação',
'LBL_IS'=>'é',
'LBL_IS_NOT'=>'não é',
'LBL_IS_BEFORE'=>'é antes',
'LBL_IS_AFTER'=>'é depois',
'LBL_STATISTICS'=>'Estatísticas',
'LBL_TICKET_ID'=>'No. Ticket',
'LBL_MY_TICKETS'=>'Meus Tickets',
"LBL_MY_FAQ"=>"Minhas FAQs",
'LBL_ESTIMATED_FINISHING_TIME'=>'Tempo Estimado de Conclusão',
'LBL_SELECT_TICKET'=>'Selecionar Ticket',
'LBL_CHANGE_OWNER'=>'Mudar Proprietário',
'LBL_CHANGE_STATUS'=>'Mudar Status',
'LBL_TICKET_TITLE'=>'Título',
'LBL_TICKET_DESCRIPTION'=>'Descrição',
'LBL_TICKET_CATEGORY'=>'Categoria',
'LBL_TICKET_PRIORITY'=>'Prioridade',

//Added vtiger_fields after 4 -- Beta
'LBL_NEW_TICKET'=>'Novo Ticket',
'LBL_TICKET_INFORMATION'=>'Dados do Ticket',

'LBL_LIST_FORM_TITLE'=>'Lista de Tickets',
'LBL_SEARCH_FORM_TITLE'=>'Busca de Ticket',

//Added vtiger_fields after RC1 - Release
'LBL_CHOOSE_A_VIEW'=>'Selecione uma Visualização...',
'LBL_ALL'=>'Todos',
'LBL_LOW'=>'Baixa',
'LBL_MEDIUM'=>'Média',
'LBL_HIGH'=>'Alta',
'LBL_CRITICAL'=>'Crítica',
//Added vtiger_fields for 4GA
'Assigned To'=>'Responsável',
'Contact Name'=>'Nome Contato',
'Priority'=>'Prioridade',
'Status'=>'Status',
'Category'=>'Categoria',
'Update History'=>'Histórico do Update',
'Created Time'=>'Hora Criação',
'Modified Time'=>'Hora Modificação',
'Title'=>'Título',
'Description'=>'Descrição',

'LBL_TICKET_CUMULATIVE_STATISTICS'=>'Estatísticas Cumulativa do Ticket:',
'LBL_CASE_TOPIC'=>'Tópico do Caso',
'LBL_OPEN'=>'Aberto',
'LBL_CLOSED'=>'Fechado',
'LBL_TOTAL'=>'Total',
'LBL_TICKET_HISTORY'=>'Histórico do Ticket:',
'LBL_CATEGORIES'=>'Categorias',
'LBL_PRIORITIES'=>'Prioridades',
'LBL_SUPPORTERS'=>'Suporte',

//Added vtiger_fields after 4_0_1
'LBL_TICKET_RESOLUTION'=>'Dados da Solução',
'Solution'=>'Solução',
'Add Comment'=>'Adicionar Comentário',
'LBL_ADD_COMMENT'=>'Adicionar Comentário',//give the same value given to the above string 'Add Comment'

//Added for 4.2 Release -- CustomView
'Ticket ID'=>'No. Ticket',
'Subject'=>'Assunto',

//Added after 4.2 alpha
'Severity'=>'Gravidade',
'Product Name'=>'Nome Produto',
'Related To'=>'Relacionado à',
'LBL_MORE'=>'Mais',

'LBL_TICKETS'=>'Tickets',

//Added on 09-12-2005
'LBL_CUMULATIVE_STATISTICS'=>'Estatísticas Acumuladas',

//Added on 12-12-2005
'LBL_CONVERT_AS_FAQ_BUTTON_TITLE'=>'Converter em FAQ',
'LBL_CONVERT_AS_FAQ_BUTTON_KEY'=>'C',
'LBL_CONVERT_AS_FAQ_BUTTON_LABEL'=>'Converter em FAQ',
'Attachment'=>'Anexo',
'LBL_COMMENT_INFORMATION'=> 'Informação Observações',

//Added for existing picklist entries

'Big Problem'=>'Problema Grande',
'Small Problem'=>'Problema Pequeno',
'Other Problem'=>'Outro Problema',

'Low'=>'Baixa',
'Normal'=>'Normal',
'High'=>'Alta',
'Urgent'=>'Urgente',

'Minor'=>'Menor',
'Major'=>'Maior',
'Feature'=>'Normal',
'Critical'=>'Crítico',

'Open'=>'Aberto',
'In Progress'=>'Em Processo',
'Wait For Response'=>'Aguarda Resposta',
'Closed'=>'Fechado',

//added to support i18n in ticket mails
'Hi' => 'Olá',
'Dear'=> 'Prezado(a)',
'LBL_PORTAL_BODY_MAILINFO' => 'O Ticket em referência foi',
'LBL_DETAIL' => 'e os detalhes do mesmo são apresentados abaixo:',
'LBL_REGARDS'=> 'Cordialmente',
'LBL_TEAM'=> 'Equipe HelpDesk',
'LBL_TICKET_DETAILS' => 'Detalhes Ticket',
'LBL_SUBJECT' => 'Assunto : ',
'created' => 'criado',
'replied' => 'respondido',
'reply'=>'Existe uma resposta para',
'customer_portal' => ' no nosso "Portal do Cliente".',
'link' => ' Você pode utilizar o seguinte link para visualizar a resposta:',
'Thanks' => 'Obrigado',
'Support_team' => 'Equipe Suporte vtiger',
'The comments are' => 'Os comentários são',
'Ticket Title' => 'Título Ticket',
'Re' => 'Re :',
// Added/Updated for vtiger CRM 5.0.4

//this label for customerportal.
'LBL_STATUS_CLOSED' =>'Closed',//Do not convert this label. This is used to check the status. If the status 'Closed' is changed in vtigerCRM server side then you have to change in customerportal language file also.
'LBL_STATUS_UPDATE' => 'Status do Ticket foi atualizado como',
'LBL_COULDNOT_CLOSED' => 'O Ticket não pode ser',
'LBL_CUSTOMER_COMMENTS' => 'O Cliente forneceu a seguinte informação adicional para sua resposta:',
'LBL_RESPOND'=> 'Por gentileza, responda este ticket o mais rápido possível.',
'LBL_REGARDS' =>'Cordialmente',
'LBL_SUPPORT_ADMIN' => 'Administrador Suporte',
'LBL_RESPONDTO_TICKETID' =>'Responder Ticket No.',
'LBL_CUSTOMER_PORTAL' => ' no Portal do Cliente - URGENTE',
'LBL_LOGIN_DETAILS' => 'Estes são seus detalhes de login no Portal do Cliente :',
'LBL_MAIL_COULDNOT_SENT' =>'A mensagem não pode ser enviada',
'LBL_USERNAME' => 'Nome Usuário :',
'LBL_PASSWORD' => 'Senha :',
'LBL_SUBJECT_PORTAL_LOGIN_DETAILS' => 'Observar os detalhes de login no Portal do Cliente',
'LBL_GIVE_MAILID' => 'Por gentileza, informe seu e-mail',
'LBL_CHECK_MAILID' => 'Por favor, verifique seu e-mail para o Portal do Cliente',
'LBL_LOGIN_REVOKED' => 'Seu login foi cancelado. Por favor, contacte o Administrador do Sistema.',
'LBL_MAIL_SENT' => 'Mensagem enviada para seu e-mail com detalhes do login no Portal do Cliente.',
'LBL_ALTBODY' => 'Este é o corpo da mensagem em texto simples para programas de e-mail que não suportam HTML',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Ticket No' => 'No. Ticket',
// END

'Hours' => 'Horas',
'Days' => 'Dias',

'From Portal' => 'Do Portal',
'HelpDesk ID' => 'ID Tickets',
);

?>
